# Generated by Django 2.2.19 on 2021-10-30 22:37

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0004_auto_20200305_1946"),
    ]

    operations = [
        migrations.AlterField(
            model_name="socialprofile",
            name="google_kind",
            field=models.CharField(
                blank=True, max_length=15, null=True, verbose_name="Google Kind"
            ),
        ),
    ]
