# Generated by Django 3.2.13 on 2022-05-03 21:58

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0026_socialprofile_edited_by_live"),
    ]

    operations = [
        # migrations.DeleteModel(
        #     name="ProxyPhoneDevice",
        # ),
    ]
