# Generated by Django 2.2.24 on 2021-11-01 11:14

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0009_auto_20210214_1722"),
    ]

    operations = [
        migrations.AlterField(
            model_name="socialprofile",
            name="twitter_language",
            field=models.CharField(
                blank=True, max_length=10, null=True, verbose_name="Twitter Language"
            ),
        ),
    ]
