# Generated by Django 2.2.25 on 2021-12-15 22:57

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0021_auto_20211214_2019"),
    ]

    operations = [
        migrations.AddField(
            model_name="socialprofile",
            name="image_avatar",
            field=models.CharField(
                blank=None,
                choices=[
                    ("socials", "Socials"),
                    ("predef", "Predefined"),
                    ("custom", "Custom"),
                ],
                default="socials",
                max_length=100,
                verbose_name="Avatar Picture",
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="image_avatar_predef",
            field=models.CharField(
                blank=None,
                choices=[
                    ("avatar1.png", "Male 1"),
                    ("avatar2.png", "Male 2"),
                    ("avatar3.png", "Female 1"),
                    ("avatar4.png", "Male 3"),
                    ("avatar5.png", "Male 4"),
                    ("avatar6.png", "Male 5"),
                    ("avatar7.png", "Male 6"),
                    ("avatar8.png", "Female 2"),
                ],
                default="avatar1.png",
                max_length=100,
                verbose_name="Predef Avatar Picture",
            ),
        ),
    ]
