# Generated by Django 2.2.9 on 2020-02-07 10:47

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0002_models_proxy"),
        ("socialprofile", "0002_auto_20170107_0237"),
    ]

    operations = []
