# Generated by Django 2.2.24 on 2021-11-29 15:13

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0011_delete_group"),
    ]

    operations = [
        migrations.AlterField(
            model_name="socialprofile",
            name="phone_number",
            field=models.CharField(
                blank=True,
                max_length=16,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Phone number must be entered in the format: '+999999999'. Up to 15 digits allowed.",
                        regex="^\\+\\d{8,15}$",
                    )
                ],
                verbose_name="Phone Number",
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="visible",
            field=models.BooleanField(
                choices=[(True, "Yes"), (False, "No")],
                default=True,
                help_text="Designates whether this user should be visible by all. Unselect this make your account private!",
                verbose_name="Visible in the Public Pages",
            ),
        ),
    ]
