# Generated by Django 2.2.24 on 2021-11-21 14:51

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0010_auto_20211101_1214"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Group",
        ),
    ]
