# Generated by Django 2.2.11 on 2020-04-03 13:25

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0006_auto_20211030_2242"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="proxysession",
            options={
                "verbose_name": "Monitor: session",
                "verbose_name_plural": "Monitor: sessions",
            },
        ),
    ]
