# Generated by Django 2.2.24 on 2021-12-03 08:58

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0019_auto_20211202_2216"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="socialprofile",
            name="last_accessed",
        ),
    ]
