# Generated by Django 2.2.24 on 2021-11-30 18:37

import django_countries.fields
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0017_auto_20211129_2305"),
    ]

    operations = [
        migrations.AlterField(
            model_name="socialprofile",
            name="country",
            field=django_countries.fields.CountryField(
                blank=True, max_length=2, null=True
            ),
        ),
    ]
