# Generated by Django 3.2.12 on 2022-03-17 09:59

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("oauth2_provider", "0005_auto_20211222_2352"),
        ("socialprofile", "0024_auto_20220111_0008"),
    ]

    operations = [
        migrations.CreateModel(
            name="ProxyIDToken",
            fields=[],
            options={
                "verbose_name": "Token: id token",
                "verbose_name_plural": "Token: id tokens",
                "proxy": True,
                "indexes": [],
                "constraints": [],
            },
            bases=("oauth2_provider.idtoken",),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="live_avatar",
            field=models.URLField(
                blank=True, max_length=500, null=True, verbose_name="Live Avatar"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="live_language",
            field=models.CharField(
                blank=True, max_length=10, null=True, verbose_name="Live Language"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="live_url",
            field=models.URLField(
                blank=True, max_length=500, null=True, verbose_name="Live Profile"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="live_username",
            field=models.CharField(
                blank=True, max_length=30, verbose_name="Live Username"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="live_verified",
            field=models.BooleanField(
                blank=True, default=False, null=True, verbose_name="Live Verified"
            ),
        ),
    ]
