# Generated by Django 4.2.16 on 2025-01-04 18:27

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0028_alter_proxysession_options"),
    ]

    operations = [
        migrations.AddField(
            model_name="socialprofile",
            name="facebook_email",
            field=models.EmailField(
                blank=True, max_length=254, null=True, verbose_name="Facebook's Email"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="google_email",
            field=models.EmailField(
                blank=True, max_length=254, null=True, verbose_name="Google's Email"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="instagram_email",
            field=models.EmailField(
                blank=True, max_length=254, null=True, verbose_name="Instagram's Email"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="live_email",
            field=models.EmailField(
                blank=True, max_length=254, null=True, verbose_name="Live's Email"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="twitter_email",
            field=models.EmailField(
                blank=True, max_length=254, null=True, verbose_name="Twitter's Email"
            ),
        ),
    ]
