# Generated by Django 3.2.13 on 2022-05-03 21:58

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0025_auto_20220317_1059"),
    ]

    operations = [
        migrations.AddField(
            model_name="socialprofile",
            name="edited_by_live",
            field=models.BooleanField(
                blank=True, default=False, verbose_name="Live edited"
            ),
        ),
    ]
