# Generated by Django 2.2.24 on 2021-12-02 21:16

import django.core.validators
import django_countries.fields
from django.db import migrations, models

import socialprofile.models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0018_auto_20211130_1937"),
    ]

    operations = [
        migrations.AlterField(
            model_name="socialprofile",
            name="country",
            field=django_countries.fields.CountryField(
                blank=True, max_length=2, null=True, verbose_name="Country"
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="edited_by_provider",
            field=models.NullBooleanField(
                default=False, verbose_name="Provider edited"
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="edited_by_user",
            field=models.NullBooleanField(default=False, verbose_name="User edited"),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="is_active",
            field=models.NullBooleanField(
                default=True,
                help_text="Designates whether this user should be treated as active. Unselect this instead of deleting accounts.",
                verbose_name="Active",
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="is_staff",
            field=models.NullBooleanField(
                default=False,
                help_text="Designates whether the user can log into this admin site.",
                verbose_name="Staff",
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="sort",
            field=socialprofile.models.IntegerRangeField(
                blank=True, default=1, null=True, verbose_name="Sort order"
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="username",
            field=models.CharField(
                error_messages={"unique": "A user with that username already exists."},
                help_text="Required. 30 characters or fewer. Letters, digits and @/./+/-/_ only",
                max_length=30,
                unique=True,
                validators=[
                    django.core.validators.RegexValidator(
                        "^[\\w.@+-]+$",
                        "Enter a valid username. This value may contain 30 characters or fewer. Only letters, numbers and @/./+/-/_ characters",
                    )
                ],
                verbose_name="Username",
            ),
        ),
        migrations.AlterField(
            model_name="socialprofile",
            name="visible",
            field=models.BooleanField(
                choices=[(True, "Yes"), (False, "No")],
                default=True,
                help_text="Designates whether this user should be visible by all. Select 'no' this make your account private!",
                verbose_name="Public",
            ),
        ),
    ]
