# Generated by Django 2.2.18 on 2021-02-14 16:22

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("socialprofile", "0008_auto_20201117_1209"),
    ]

    operations = [
        migrations.RenameField(
            model_name="socialprofile",
            old_name="manually_edited",
            new_name="edited_by_user",
        ),
        migrations.RemoveField(
            model_name="socialprofile",
            name="editByGoogle",
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="edited_by_provider",
            field=models.NullBooleanField(
                default=False, verbose_name="Provider Edit User's Info"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="twitter_language",
            field=models.CharField(
                blank=True, max_length=2, null=True, verbose_name="Twitter Language"
            ),
        ),
        migrations.AddField(
            model_name="socialprofile",
            name="twitter_verified",
            field=models.NullBooleanField(
                default=False, verbose_name="Twitter Verified"
            ),
        ),
    ]
